#ifndef Application_h
#define Application_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "BaseApplication.h"
#include "Config.h"
#include "CommandLineArguments.h"
#include "Counter.h"
#include "File.h"
#include "FileList.h"
#include "IconEngine.h"

#include <memory>

class MainWindow;

//* application controler
class Application: public BaseApplication, private Base::Counter<Application>
{

    Q_OBJECT

    public:

    //* constructor
    explicit Application( CommandLineArguments );

    //* application manager
    bool initApplicationManager() override;

    //* create all widgets
    bool realizeWidget() override;

    //* file list
    FileList& recentFiles() const
    { return *recentFiles_; }

    //* retrieves top layout
    MainWindow& mainWindow() const
    { return *mainWindow_; }

    //*@name application information
    //@{

    //* command line parser
    CommandLineParser commandLineParser( CommandLineArguments = CommandLineArguments(), bool ignoreWarnings = true ) const override;

    //* command line help
    void usage() const override;

    //* application name
    QString applicationName() const override
    { return "Textool"; }

    //* application icon
    QIcon applicationIcon() const override
    { return IconEngine::get( ":/textool.png" ); }

    // application version
    QString applicationVersion() const override
    { return VERSION; }

    //@}


    public Q_SLOTS:

    //* add recent file
    void addRecentFile( File );

    protected Q_SLOTS:

    //* configuration
    void _configuration() override;

    //* process request from application manager
    bool _processCommand( Server::ServerCommand ) override;

    private Q_SLOTS:

    //* update configuration
    void _updateConfiguration();

    private:

    //* recent files list
    std::unique_ptr<FileList> recentFiles_;

    //* top widget
    MainWindow *mainWindow_ = nullptr;

};

#endif
