#ifndef ButtonFrame_h
#define ButtonFrame_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "LatexCommand.h"
#include "TexFile.h"

#include <QWidget>
#include <QPushButton>

//* Set of buttons connected to latex related actions
class ButtonFrame: public QWidget, private Base::Counter<ButtonFrame>
{

    Q_OBJECT

    public:

    //* constructor
    explicit ButtonFrame( QWidget* parent );

    //* edit button
    /** it is needed because connected to MainWindow slot */
    QPushButton& editButton() const
    { return *editButton_; }

    //* set file
    void setFile( const File& value )
    {
        file_ = TexFile( value );
        updateButtons();
    }

    //* update buttons
    void updateButtons();

    Q_SIGNALS:

    //* recent file added
    void recentFileAdded( const File& );

    //* request latex command
    void commandRequested( const Latex::Command& );

    //* message
    void messageAvailable( const QString& );

    private Q_SLOTS:

    //* clean
    void _clean()
    {
        emit commandRequested( Latex::Command( Latex::Command::Type::Clean, {file_} ) );
        updateButtons();
    }

    //* run dvi viewer
    void _viewDvi();

    //* run PS viewer
    void _viewPostscript();

    //* run PDF viewer
    void _viewPdf();

    private:

    //* file
    TexFile file_;

    //* edit tex button
    QPushButton* editButton_ = nullptr;

    //* view dvi  button
    QPushButton* viewDviButton_ = nullptr;

    //* view ps button
    QPushButton* viewPostscriptButton_ = nullptr;

    //* view pdf button
    QPushButton* viewPdfButton_ = nullptr;

    //* clean
    QPushButton* cleanButton_ = nullptr;

};

#endif
