#ifndef FigureFrame_h
#define FigureFrame_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "TabWidget.h"
#include "Debug.h"
#include "File.h"
#include "LatexCommand.h"
#include "Options.h"
#include "FigureModel.h"

class TreeView;

//* parse input file and display includes recursively
class FigureFrame:public TabWidget
{

    Q_OBJECT

    public:

    //* constructor
    explicit FigureFrame( QTabWidget* parent );

    //* set file
    void setFile( const File& );

    Q_SIGNALS:

    //* request latex command
    void commandRequested( const Latex::Command& );

    //* message
    void messageAvailable( const QString& );

    public Q_SLOTS:

    //* request update
    void requestUpdate();

    //* update figures
    void update( const FileRecord::List& figures )
    { model_.set( figures ); }

    private Q_SLOTS:

    //* update actions enability
    void _updateActions();

    //* edit a file from list view
    void _viewFigure();

    private:

    //* actions
    void _installActions();

    //* file
    File file_;

    //* model
    FigureModel model_;

    //* list
    TreeView* list_;

    //* view figure action
    QAction* viewFigureAction_;

    //* reload
    QAction* reloadAction_;

};

#endif
