#ifndef IncludeFile_h
#define IncludeFile_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "FileRecord.h"

//* needed to store hierarchical information on top of FileRecord
class IncludeFile: public FileRecord
{
    public:

    //* construct a color objects from any argument out of which you could make a qcolor
    template< typename... Args >
    explicit IncludeFile( Args&&... args ):
        FileRecord( std::forward<Args>(args)... ),
        selected_( true )
    {}

    //* parent
    const FileRecord& parent() const
    { return parent_; }

    //* set parent
    void setParent( const FileRecord& record )
    { parent_ = record; }

    //* set item selected
    void setSelected( bool value )
    { selected_ = value; }

    //* true if selected
    bool isSelected() const
    { return selected_; }

    //* returns true if this record is a child of argument
    bool isChild( const IncludeFile& record ) const
    { return parent_.file() == record.file(); }

    //* list
    using List = QList<IncludeFile>;

    private:

    //* parent File record, if any
    FileRecord parent_;

    //* selected
    bool selected_;

};

#endif
