#ifndef IncludeFileModel_h
#define IncludeFileModel_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "IncludeFile.h"
#include "TreeModel.h"

#include <array>

//* FileRecord model. Store File records in hierarchy list.
class IncludeFileModel : public TreeModel<IncludeFile>, private Base::Counter<IncludeFileModel>
{

    Q_OBJECT

    public:

    //* column type enumeration
    enum ColumnType
    {
        FileName,
        Selection,
        Empty,
        nColumns
    };

    //* constructor
    explicit IncludeFileModel(QObject* = nullptr);

    //*@name methods reimplemented from base class
    //@{

    // return File for a given index
    QVariant data( const QModelIndex&, int ) const override;

    //* header data
    QVariant headerData( int, Qt::Orientation, int = Qt::DisplayRole ) const override;

    //* number of columns for a given index
    int columnCount( const QModelIndex& = QModelIndex() ) const override
    { return nColumns; }

    //@}

    private:

    //* column titles
    const std::array<QString, nColumns> columnTitles_ =
    {{
        tr( "File" ),
        tr( "Included" ),
        QString()
    }};

};

#endif
