/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CppUtil.h"
#include "LatexCommand.h"

namespace Latex
{

    //___________________________________________________________________
    const Command::NameMap& Command::_commandNames()
    {
        static const auto names = Base::makeT<NameMap>( {
            { Type::None, QObject::tr( "none" )},
            { Type::Latex, QObject::tr( "run Latex" )},
            { Type::PDFLatex, QObject::tr( "run PdfLatex" )},
            { Type::Bibtex, QObject::tr( "run Bibtex" )},
            { Type::DviPS, QObject::tr( "convert Dvi to PS" )},
            { Type::DviPDF, QObject::tr( "convert Dvi to PDF" )},
            { Type::PS2PDF, QObject::tr( "convert PS to PDF" )},
            { Type::CheckCitations, QObject::tr( "check citations" )},
            { Type::CheckCitationOrder, QObject::tr( "check citations order" )},
            { Type::CheckLabels, QObject::tr( "check labels" )},
            { Type::CheckReferences, QObject::tr( "check references" )},
            { Type::FindIncludes, QObject::tr( "find included latex files" )},
            { Type::FindFigures, QObject::tr( "find figures" )},
            { Type::ToggleIncludeFile, QObject::tr( "toggle include file" )},
            { Type::Clean, QObject::tr( "remove temporary files" )}
        });

        return names;
    }

    //___________________________________________________________________
    int& Command::_counter()
    {
        static int counter( 0 );
        return counter;
    }

    //___________________________________________________________________
    Command::Command( Type type, QStringList&& arguments ):
        Counter( "Latex::Command" ),
        id_( _counter()++ ),
        type_( type ),
        arguments_( std::move( arguments ) )
    {}

    #if QT_VERSION < 0x040800
    //___________________________________________________________________
    Command::Command( Type type, std::initializer_list<QString>&& arguments ):
        Command( type, Base::makeT<QStringList>( std::move( arguments ) ) )
    {}
    #endif

    //___________________________________________________________________
    File Command::path() const
    {
        switch( type_ )
        {
            case Type::Latex:
            case Type::PDFLatex:
            case Type::Bibtex:
            case Type::DviPS:
            case Type::DviPDF:
            case Type::PS2PDF:
            case Type::CheckCitations:
            case Type::CheckCitationOrder:
            case Type::CheckLabels:
            case Type::CheckReferences:
            case Type::FindIncludes:
            case Type::FindFigures:
            case Type::Clean:
            return File( arguments_[0] );

            default: return File();
        }

    }

}
