/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "LatexCommandDialog.h"

#include "ColumnSelectionMenu.h"
#include "ColumnSortingMenu.h"
#include "ContextMenu.h"
#include "TreeView.h"

#include <QHeaderView>
#include <QShortcut>

namespace Latex
{
    //__________________________________________________
    CommandDialog::CommandDialog( QWidget* parent ):
        CustomDialog( parent, CloseButton )
    {

        Debug::Throw( "Latex::CommandDialog::CommandDialog.\n" );
        setWindowTitle( tr( "Commands" ) );

        // customize layout
        layout()->setMargin(0);
        layout()->setSpacing(0);
        buttonLayout().setMargin(5);

        setOptionName( "LATEX_COMMAND_DIALOG" );
        mainLayout().addWidget( list_ = new TreeView(this) );

        list_->header()->hide();
        list_->setSortingEnabled( true );
        list_->setModel( &model_ );
        list_->setSelectionMode( TreeView::ContiguousSelection );

        QMenu* menu( new ContextMenu( &list() ) );
        menu->addMenu( new ColumnSortingMenu( menu, &list() ) );
        menu->addMenu( new ColumnSelectionMenu( menu, &list() ) );

        // ok button
        connect( &okButton(), SIGNAL(pressed()), SLOT(close()) );

        // close accelerator
        new QShortcut( QKeySequence::Close, this, SLOT(close()) );

    }

    //_____________________________________________________________
    void CommandDialog::closeEvent( QCloseEvent* event )
    {
        Debug::Throw( "CommandDialog::closeEvent.\n" );
        emit dialogHidden();
        return CustomDialog::closeEvent( event );
    }

}
