/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "LatexCommandModel.h"

#include "TimeStamp.h"
#include "XmlOptions.h"

namespace Latex
{

    //_______________________________________________________________
    CommandModel::CommandModel( QObject* parent ):
        ListModel( parent ),
        Counter( "Latex::CommandModel" )
    {}

    //__________________________________________________________________
    QVariant CommandModel::data( const QModelIndex& index, int role ) const
    {

        // check index
        if( !contains( index ) ) return QVariant();

        // retrieve associated command
        const Command& command( get()[index.row()] );

        // return text associated to command and column
        if( role == Qt::DisplayRole ) {

            switch( index.column() )
            {

                case Name: return command.name();
                case Path: return command.path().get();
                default: return QVariant();
            }

        }

        return QVariant();

    }

    //__________________________________________________________________
    QVariant CommandModel::headerData(int section, Qt::Orientation orientation, int role) const
    {

        if(
            orientation == Qt::Horizontal &&
            role == Qt::DisplayRole &&
            section >= 0 &&
            section < nColumns )
        { return columnTitles_[section]; }

        // return empty
        return QVariant();

    }

}
