#ifndef MenuBar_h
#define MenuBar_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "Debug.h"
#include "FileRecord.h"
#include "ValidFileThread.h"

#include <QMenuBar>
#include <QList>
#include <QPair>

class RecentFilesMenu;

//* menu bar
class MenuBar:public QMenuBar, private Base::Counter<MenuBar>
{

    //* Qt meta object declaration
    Q_OBJECT

    public:

    //* creator
    explicit MenuBar( QWidget* );

    //* recent files menu
    RecentFilesMenu& recentFilesMenu() const
    { return *recentFilesMenu_; }

    protected Q_SLOTS:

    //* process records from threads
    void _processRecords( const FileRecord::List&, bool );

    private Q_SLOTS:

    // update edition menu
    void _updateEditionMenu();

    private:

    // valid file thread
    ValidFileThread thread_;

    // recent file menu
    RecentFilesMenu* recentFilesMenu_ = nullptr;

    // edition
    QMenu* editionMenu_ = nullptr;

    //* map actions to file recors
    using ActionPair = QPair<QAction*, FileRecord>;
    using ActionMap = QList<ActionPair>;

    //* map actions to FileRecords
    ActionMap editionActions_;

};

#endif
