#ifndef StatusBar_h
#define StatusBar_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ProgressStatusBar.h"

#include <QProgressBar>

//* customized status bar for selection frame
class StatusBar: public ProgressStatusBar
{

    Q_OBJECT

    public:

    //* constructor
    explicit StatusBar( QWidget* );

    public Q_SLOTS:

    //* set maximum
    void setMaximum( int value )
    {
        maximum_ = value;
        progressBar().setMaximum( nCycles_*maximum_ );
    }

    //* set n cycles
    void setNCycles( int value )
    {
        nCycles_ = value;
        progressBar().setMaximum( nCycles_*maximum_ );
    }

    //* reset cycle
    void resetCycle()
    { cycle_ = 0; }

    //* increment cycle
    void incrementCycle()
    { ++cycle_; }

    //* set progress
    void setValue( int value )
    {
        progressBar().setValue( cycle_*maximum_ + value );
        if( progressBar().maximum() > 0 ) showProgressBar();
    }

    private:

    //* maximum
    int maximum_;

    //* cycles
    int nCycles_;

    //* current cycle
    int cycle_;

};

#endif
